/*
 * Name: Object
 * Type: WBTApi
 *
 * Copyright (C) 2003,2004 by 4system
 * All Rights Reserved.
 *
 * $Id: object.js,v 1.9 2005/01/18 14:04:42 a.wojtis Exp $
 */ 

function destroy(obj) {
	delete obj;
}

function WBTObject()
{
	this.setID("WBTObject"+(WBTObject.count++)); 
	this.isChild = false;
	this.created = false;
	this.parent = null;
	this.children = []; 
}

WBTObject.prototype.setID = function(id)
{
	if (this.id) delete WBTObject.all[this.id];
	this.id = id;
	WBTObject.all[this.id] = this;
}; 

WBTObject.prototype.addChild = function(o)
{
	if (o.isChild) o.parent.removeChild(o);
	o.isChild = true;
	o.parent = this;
	if (this.created) o.create();
	this.children[this.children.length] = o;
	return o;
}; 

WBTObject.prototype.removeChild = function(o)
{
	var l = this.children.length;
	for (var i=0;i<l && this.children[i]!=o;i++);
	if (i!=l) {
		o.invokeEvent("BeforeRemove");
		o.created=false;
		o.invokeEvent("Remove");
		o.isChild = false;
		o.parent = null;
		this.children[i] = this.children[l-1];
		this.children[l-1] = null;
		this.children.length--;
	}
};

WBTObject.prototype.create = function()
{
	this.specificCreate();
	this.created = true;
	var l = this.children.length;
	for (var i=0;i<l;i++) this.children[i].create();
	this.invokeEvent("Create");
}; 

WBTObject.prototype.free = function()
{
	this.invokeEvent("BeforeRemove");
	this.deleteAllChildren();
	this.specificRemove();
	this.created = false;
	this.invokeEvent("Remove");
	this.invokeEvent("Free");
}; 

WBTObject.prototype.deleteChild = function(o) {
	var l = this.children.length;
	for (var i=0;i<l && this.children[i]!=o;i++);
	if (i!=l) {
		this.children[i] = this.children[l-1];
		this.children[l-1] = null;
		this.children.length--;
		o.free();
		o = null;
	}
};

WBTObject.prototype.deleteAllChildren = function()
{
	while (this.children.length > 0) {
		this.children[this.children.length - 1].free();
		delete this.children[this.children.length - 1];
		this.children.pop();
	}
}; 

WBTObject.prototype.findChildByName = function(name)
{
	for (var i=0; i<this.children.length; i++) {
		if (this.children[i].id == name) return this.children[i];
	}
	return null;    
};

WBTObject.prototype.invokeEventForAllObj = function(objArray, type, args)
{
	var res = false;
	for (var i = 0; i < objArray.length; i++) {
		res = (res || objArray[i].invokeEvent(type, args));
	}
	
	return res;
}

WBTObject.prototype.invokeEvent = function(type, args)
{
	try {
		if (this["on" + type]) return this["on" + type](window.event, args);
	} catch (e) {}
	return false;
}; 

WBTObject.prototype.actionRunScript = function(s) 
{
	if (runScriptOnError) {
		runScriptSrc = unescape(s);
		window.onerror = runScriptOnError;
	}
	var vars = "var event=window.event;";
	eval(vars + unescape(s));
	if (runScriptOnError) {
		runScriptSrc = "";
		window.onerror = null;
	}
}

var runScriptSrc = "";

function runScriptOnError(msg, url, lnum) {
	log.error(msg, 'Bd wykonania skryptu: ' + runScriptSrc + '\n');
	return true;
}

WBTObject.prototype.specificRemove = function() {};
WBTObject.prototype.specificCreate = function() {};

WBTObject.count = 0;
WBTObject.all = [];

/********************************************************************/
